#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class reference_values:
    fluent_name = ...
    child_names = ...
    area = ...
    depth = ...
    density = ...
    enthalpy = ...
    length = ...
    pressure = ...
    temperature = ...
    yplus = ...
    velocity = ...
    viscosity = ...
    zone = ...
    command_names = ...

    def compute(self, from_zone_type: str, from_zone_name: str, phase: str):
        """
        'compute' command.
        
        Parameters
        ----------
            from_zone_type : str
                'from_zone_type' child.
            from_zone_name : str
                'from_zone_name' child.
            phase : str
                'phase' child.
        
        """

    def list_val(self, ):
        """
        'list_val' command.
        """

